# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_time.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import delivery_category_pb2 as v1_dot_rules_dot_delivery__category__pb2
from omni.pro.protos.v1.rules import delivery_locality_pb2 as v1_dot_rules_dot_delivery__locality__pb2
from omni.pro.protos.v1.rules import delivery_method_pb2 as v1_dot_rules_dot_delivery__method__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cv1/rules/delivery_time.proto\x12\'pro.omni.oms.api.v1.rules.delivery_time\x1a\x11\x63ommon/base.proto\x1a\x1ev1/rules/delivery_method.proto\x1a v1/rules/delivery_locality.proto\x1a\x18v1/rules/warehouse.proto\x1a v1/rules/delivery_category.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xc9\x06\n\x0c\x44\x65liveryTime\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12S\n\x10\x64\x65livery_methods\x18\x04 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12\x45\n\rwarehouses_to\x18\x05 \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12G\n\x0fwarehouses_from\x18\x06 \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12Y\n\x12locality_available\x18\x07 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocality\x12\x11\n\ttime_type\x18\x08 \x01(\t\x12.\n\tvalue_min\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12.\n\tvalue_max\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12-\n\tinversely\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x17\n\x0fvariable_factor\x18\x0c \x01(\t\x12\x17\n\x0foperator_factor\x18\r \x01(\t\x12\x15\n\ramount_factor\x18\x0e \x01(\x02\x12\x64\n\x1d\x63\x61tegory_template_not_allowed\x18\x0f \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_category.DeliveryCategory\x12*\n\x06\x61\x63tive\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x11 \x01(\t\x12?\n\x0cobject_audit\x18\x12 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xd1\x03\n\x19\x44\x65liveryTimeCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x1d\n\x15locality_available_id\x18\x03 \x01(\t\x12\x11\n\ttime_type\x18\x04 \x01(\t\x12\x11\n\tvalue_min\x18\x05 \x01(\x05\x12\x11\n\tvalue_max\x18\x06 \x01(\x05\x12\x18\n\x10warehouse_to_ids\x18\x07 \x03(\x05\x12\x1a\n\x12warehouse_from_ids\x18\x08 \x03(\x05\x12\x1b\n\x13\x64\x65livery_method_ids\x18\t \x03(\t\x12-\n\tinversely\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x0b \x01(\t\x12\x17\n\x0fvariable_factor\x18\x0c \x01(\t\x12\x17\n\x0foperator_factor\x18\r \x01(\t\x12\x15\n\ramount_factor\x18\x0e \x01(\x02\x12(\n category_template_not_allowed_id\x18\x0f \x01(\t\x12\x36\n\x07\x63ontext\x18\x10 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1a\x44\x65liveryTimeCreateResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf5\x02\n\x17\x44\x65liveryTimeReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xef\x01\n\x18\x44\x65liveryTimeReadResponse\x12M\n\x0e\x64\x65livery_times\x18\x01 \x03(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa1\x01\n\x19\x44\x65liveryTimeUpdateRequest\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1a\x44\x65liveryTimeUpdateResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"_\n\x19\x44\x65liveryTimeDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1a\x44\x65liveryTimeDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x84\x01\n\x16\x41\x64\x64WarehousesToRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x18\n\x10warehouse_to_ids\x18\x02 \x03(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb2\x01\n\x17\x41\x64\x64WarehousesToResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x87\x01\n\x19RemoveWarehousesToRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x18\n\x10warehouse_to_ids\x18\x02 \x03(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1aRemoveWarehousesToResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x88\x01\n\x18\x41\x64\x64WarehousesFromRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x1a\n\x12warehouse_from_ids\x18\x02 \x03(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb4\x01\n\x19\x41\x64\x64WarehousesFromResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8b\x01\n\x1bRemoveWarehousesFromRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x1a\n\x12warehouse_from_ids\x18\x02 \x03(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb7\x01\n\x1cRemoveWarehousesFromResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x89\x01\n\x18\x41\x64\x64\x44\x65liveryMethodRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x1b\n\x13\x64\x65livery_method_ids\x18\x02 \x03(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb4\x01\n\x19\x41\x64\x64\x44\x65liveryMethodResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8c\x01\n\x1bRemoveDeliveryMethodRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\t\x12\x1b\n\x13\x64\x65livery_method_ids\x18\x02 \x03(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb7\x01\n\x1cRemoveDeliveryMethodResponse\x12L\n\rdelivery_time\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTime\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe0\x0c\n\x13\x44\x65liveryTimeService\x12\x9f\x01\n\x12\x44\x65liveryTimeCreate\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeCreateRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeCreateResponse"\x00\x12\x99\x01\n\x10\x44\x65liveryTimeRead\x12@.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeReadRequest\x1a\x41.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeReadResponse"\x00\x12\x9f\x01\n\x12\x44\x65liveryTimeUpdate\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeUpdateRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeUpdateResponse"\x00\x12\x9f\x01\n\x12\x44\x65liveryTimeDelete\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeDeleteRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.DeliveryTimeDeleteResponse"\x00\x12\x96\x01\n\x0f\x41\x64\x64WarehousesTo\x12?.pro.omni.oms.api.v1.rules.delivery_time.AddWarehousesToRequest\x1a@.pro.omni.oms.api.v1.rules.delivery_time.AddWarehousesToResponse"\x00\x12\x9f\x01\n\x12RemoveWarehousesTo\x12\x42.pro.omni.oms.api.v1.rules.delivery_time.RemoveWarehousesToRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_time.RemoveWarehousesToResponse"\x00\x12\x9c\x01\n\x11\x41\x64\x64WarehousesFrom\x12\x41.pro.omni.oms.api.v1.rules.delivery_time.AddWarehousesFromRequest\x1a\x42.pro.omni.oms.api.v1.rules.delivery_time.AddWarehousesFromResponse"\x00\x12\xa5\x01\n\x14RemoveWarehousesFrom\x12\x44.pro.omni.oms.api.v1.rules.delivery_time.RemoveWarehousesFromRequest\x1a\x45.pro.omni.oms.api.v1.rules.delivery_time.RemoveWarehousesFromResponse"\x00\x12\x9c\x01\n\x11\x41\x64\x64\x44\x65liveryMethod\x12\x41.pro.omni.oms.api.v1.rules.delivery_time.AddDeliveryMethodRequest\x1a\x42.pro.omni.oms.api.v1.rules.delivery_time.AddDeliveryMethodResponse"\x00\x12\xa5\x01\n\x14RemoveDeliveryMethod\x12\x44.pro.omni.oms.api.v1.rules.delivery_time.RemoveDeliveryMethodRequest\x1a\x45.pro.omni.oms.api.v1.rules.delivery_time.RemoveDeliveryMethodResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_time_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYTIME"]._serialized_start = 251
    _globals["_DELIVERYTIME"]._serialized_end = 1092
    _globals["_DELIVERYTIMECREATEREQUEST"]._serialized_start = 1095
    _globals["_DELIVERYTIMECREATEREQUEST"]._serialized_end = 1560
    _globals["_DELIVERYTIMECREATERESPONSE"]._serialized_start = 1563
    _globals["_DELIVERYTIMECREATERESPONSE"]._serialized_end = 1744
    _globals["_DELIVERYTIMEREADREQUEST"]._serialized_start = 1747
    _globals["_DELIVERYTIMEREADREQUEST"]._serialized_end = 2120
    _globals["_DELIVERYTIMEREADRESPONSE"]._serialized_start = 2123
    _globals["_DELIVERYTIMEREADRESPONSE"]._serialized_end = 2362
    _globals["_DELIVERYTIMEUPDATEREQUEST"]._serialized_start = 2365
    _globals["_DELIVERYTIMEUPDATEREQUEST"]._serialized_end = 2526
    _globals["_DELIVERYTIMEUPDATERESPONSE"]._serialized_start = 2529
    _globals["_DELIVERYTIMEUPDATERESPONSE"]._serialized_end = 2710
    _globals["_DELIVERYTIMEDELETEREQUEST"]._serialized_start = 2712
    _globals["_DELIVERYTIMEDELETEREQUEST"]._serialized_end = 2807
    _globals["_DELIVERYTIMEDELETERESPONSE"]._serialized_start = 2809
    _globals["_DELIVERYTIMEDELETERESPONSE"]._serialized_end = 2912
    _globals["_ADDWAREHOUSESTOREQUEST"]._serialized_start = 2915
    _globals["_ADDWAREHOUSESTOREQUEST"]._serialized_end = 3047
    _globals["_ADDWAREHOUSESTORESPONSE"]._serialized_start = 3050
    _globals["_ADDWAREHOUSESTORESPONSE"]._serialized_end = 3228
    _globals["_REMOVEWAREHOUSESTOREQUEST"]._serialized_start = 3231
    _globals["_REMOVEWAREHOUSESTOREQUEST"]._serialized_end = 3366
    _globals["_REMOVEWAREHOUSESTORESPONSE"]._serialized_start = 3369
    _globals["_REMOVEWAREHOUSESTORESPONSE"]._serialized_end = 3550
    _globals["_ADDWAREHOUSESFROMREQUEST"]._serialized_start = 3553
    _globals["_ADDWAREHOUSESFROMREQUEST"]._serialized_end = 3689
    _globals["_ADDWAREHOUSESFROMRESPONSE"]._serialized_start = 3692
    _globals["_ADDWAREHOUSESFROMRESPONSE"]._serialized_end = 3872
    _globals["_REMOVEWAREHOUSESFROMREQUEST"]._serialized_start = 3875
    _globals["_REMOVEWAREHOUSESFROMREQUEST"]._serialized_end = 4014
    _globals["_REMOVEWAREHOUSESFROMRESPONSE"]._serialized_start = 4017
    _globals["_REMOVEWAREHOUSESFROMRESPONSE"]._serialized_end = 4200
    _globals["_ADDDELIVERYMETHODREQUEST"]._serialized_start = 4203
    _globals["_ADDDELIVERYMETHODREQUEST"]._serialized_end = 4340
    _globals["_ADDDELIVERYMETHODRESPONSE"]._serialized_start = 4343
    _globals["_ADDDELIVERYMETHODRESPONSE"]._serialized_end = 4523
    _globals["_REMOVEDELIVERYMETHODREQUEST"]._serialized_start = 4526
    _globals["_REMOVEDELIVERYMETHODREQUEST"]._serialized_end = 4666
    _globals["_REMOVEDELIVERYMETHODRESPONSE"]._serialized_start = 4669
    _globals["_REMOVEDELIVERYMETHODRESPONSE"]._serialized_end = 4852
    _globals["_DELIVERYTIMESERVICE"]._serialized_start = 4855
    _globals["_DELIVERYTIMESERVICE"]._serialized_end = 6487
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import quant_pb2 as v1_dot_stock_dot_quant__pb2


class QuantServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.QuantCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.quant.QuantService/QuantCreate",
            request_serializer=v1_dot_stock_dot_quant__pb2.QuantCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_quant__pb2.QuantCreateResponse.FromString,
        )
        self.QuantRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.quant.QuantService/QuantRead",
            request_serializer=v1_dot_stock_dot_quant__pb2.QuantReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_quant__pb2.QuantReadResponse.FromString,
        )
        self.QuantUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.quant.QuantService/QuantUpdate",
            request_serializer=v1_dot_stock_dot_quant__pb2.QuantUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_quant__pb2.QuantUpdateResponse.FromString,
        )
        self.QuantDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.quant.QuantService/QuantDelete",
            request_serializer=v1_dot_stock_dot_quant__pb2.QuantDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_quant__pb2.QuantDeleteResponse.FromString,
        )
        self.ProductAvailable = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.quant.QuantService/ProductAvailable",
            request_serializer=v1_dot_stock_dot_quant__pb2.ProductAvailableRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_quant__pb2.ProductAvailableResponse.FromString,
        )


class QuantServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def QuantCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QuantRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QuantUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def QuantDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductAvailable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_QuantServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "QuantCreate": grpc.unary_unary_rpc_method_handler(
            servicer.QuantCreate,
            request_deserializer=v1_dot_stock_dot_quant__pb2.QuantCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_quant__pb2.QuantCreateResponse.SerializeToString,
        ),
        "QuantRead": grpc.unary_unary_rpc_method_handler(
            servicer.QuantRead,
            request_deserializer=v1_dot_stock_dot_quant__pb2.QuantReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_quant__pb2.QuantReadResponse.SerializeToString,
        ),
        "QuantUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.QuantUpdate,
            request_deserializer=v1_dot_stock_dot_quant__pb2.QuantUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_quant__pb2.QuantUpdateResponse.SerializeToString,
        ),
        "QuantDelete": grpc.unary_unary_rpc_method_handler(
            servicer.QuantDelete,
            request_deserializer=v1_dot_stock_dot_quant__pb2.QuantDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_quant__pb2.QuantDeleteResponse.SerializeToString,
        ),
        "ProductAvailable": grpc.unary_unary_rpc_method_handler(
            servicer.ProductAvailable,
            request_deserializer=v1_dot_stock_dot_quant__pb2.ProductAvailableRequest.FromString,
            response_serializer=v1_dot_stock_dot_quant__pb2.ProductAvailableResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.quant.QuantService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class QuantService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def QuantCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.quant.QuantService/QuantCreate",
            v1_dot_stock_dot_quant__pb2.QuantCreateRequest.SerializeToString,
            v1_dot_stock_dot_quant__pb2.QuantCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def QuantRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.quant.QuantService/QuantRead",
            v1_dot_stock_dot_quant__pb2.QuantReadRequest.SerializeToString,
            v1_dot_stock_dot_quant__pb2.QuantReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def QuantUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.quant.QuantService/QuantUpdate",
            v1_dot_stock_dot_quant__pb2.QuantUpdateRequest.SerializeToString,
            v1_dot_stock_dot_quant__pb2.QuantUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def QuantDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.quant.QuantService/QuantDelete",
            v1_dot_stock_dot_quant__pb2.QuantDeleteRequest.SerializeToString,
            v1_dot_stock_dot_quant__pb2.QuantDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductAvailable(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.quant.QuantService/ProductAvailable",
            v1_dot_stock_dot_quant__pb2.ProductAvailableRequest.SerializeToString,
            v1_dot_stock_dot_quant__pb2.ProductAvailableResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import holidays_pb2 as v1_dot_rules_dot_holidays__pb2


class HolidaysServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HolidaysCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysCreate",
            request_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysCreateResponse.FromString,
        )
        self.HolidaysRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysRead",
            request_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysReadResponse.FromString,
        )
        self.HolidaysUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysUpdate",
            request_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysUpdateResponse.FromString,
        )
        self.HolidaysDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysDelete",
            request_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysDeleteResponse.FromString,
        )


class HolidaysServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HolidaysCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HolidaysRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HolidaysUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def HolidaysDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_HolidaysServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "HolidaysCreate": grpc.unary_unary_rpc_method_handler(
            servicer.HolidaysCreate,
            request_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysCreateResponse.SerializeToString,
        ),
        "HolidaysRead": grpc.unary_unary_rpc_method_handler(
            servicer.HolidaysRead,
            request_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysReadResponse.SerializeToString,
        ),
        "HolidaysUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.HolidaysUpdate,
            request_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysUpdateResponse.SerializeToString,
        ),
        "HolidaysDelete": grpc.unary_unary_rpc_method_handler(
            servicer.HolidaysDelete,
            request_deserializer=v1_dot_rules_dot_holidays__pb2.HolidaysDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_holidays__pb2.HolidaysDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.holidays.HolidaysService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class HolidaysService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HolidaysCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysCreate",
            v1_dot_rules_dot_holidays__pb2.HolidaysCreateRequest.SerializeToString,
            v1_dot_rules_dot_holidays__pb2.HolidaysCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def HolidaysRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysRead",
            v1_dot_rules_dot_holidays__pb2.HolidaysReadRequest.SerializeToString,
            v1_dot_rules_dot_holidays__pb2.HolidaysReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def HolidaysUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysUpdate",
            v1_dot_rules_dot_holidays__pb2.HolidaysUpdateRequest.SerializeToString,
            v1_dot_rules_dot_holidays__pb2.HolidaysUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def HolidaysDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.holidays.HolidaysService/HolidaysDelete",
            v1_dot_rules_dot_holidays__pb2.HolidaysDeleteRequest.SerializeToString,
            v1_dot_rules_dot_holidays__pb2.HolidaysDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/schedule_work_line.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!v1/rules/schedule_work_line.proto\x12,pro.omni.oms.api.v1.rules.schedule_work_line\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xd9\x01\n\x10ScheduleWorkLine\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03\x64\x61y\x18\x02 \x01(\t\x12\x14\n\x0copening_time\x18\x03 \x01(\t\x12\x14\n\x0c\x63losing_time\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x06 \x01(\t\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xa5\x01\n\x1dScheduleWorkLineCreateRequest\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\t\x12\x14\n\x0copening_time\x18\x02 \x01(\t\x12\x14\n\x0c\x63losing_time\x18\x03 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc7\x01\n\x1eScheduleWorkLineCreateResponse\x12Z\n\x12schedule_work_line\x18\x01 \x01(\x0b\x32>.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf9\x02\n\x1bScheduleWorkLineReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x81\x02\n\x1cScheduleWorkLineReadResponse\x12[\n\x13schedule_work_lines\x18\x01 \x03(\x0b\x32>.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLine\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xb3\x01\n\x1dScheduleWorkLineUpdateRequest\x12Z\n\x12schedule_work_line\x18\x01 \x01(\x0b\x32>.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLine\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc7\x01\n\x1eScheduleWorkLineUpdateResponse\x12Z\n\x12schedule_work_line\x18\x01 \x01(\x0b\x32>.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLine\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"c\n\x1dScheduleWorkLineDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"k\n\x1eScheduleWorkLineDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf3\x05\n\x17ScheduleWorkLineService\x12\xb5\x01\n\x16ScheduleWorkLineCreate\x12K.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineCreateRequest\x1aL.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineCreateResponse"\x00\x12\xaf\x01\n\x14ScheduleWorkLineRead\x12I.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineReadRequest\x1aJ.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineReadResponse"\x00\x12\xb5\x01\n\x16ScheduleWorkLineUpdate\x12K.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineUpdateRequest\x1aL.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineUpdateResponse"\x00\x12\xb5\x01\n\x16ScheduleWorkLineDelete\x12K.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineDeleteRequest\x1aL.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLineDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.schedule_work_line_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_SCHEDULEWORKLINE"]._serialized_start = 168
    _globals["_SCHEDULEWORKLINE"]._serialized_end = 385
    _globals["_SCHEDULEWORKLINECREATEREQUEST"]._serialized_start = 388
    _globals["_SCHEDULEWORKLINECREATEREQUEST"]._serialized_end = 553
    _globals["_SCHEDULEWORKLINECREATERESPONSE"]._serialized_start = 556
    _globals["_SCHEDULEWORKLINECREATERESPONSE"]._serialized_end = 755
    _globals["_SCHEDULEWORKLINEREADREQUEST"]._serialized_start = 758
    _globals["_SCHEDULEWORKLINEREADREQUEST"]._serialized_end = 1135
    _globals["_SCHEDULEWORKLINEREADRESPONSE"]._serialized_start = 1138
    _globals["_SCHEDULEWORKLINEREADRESPONSE"]._serialized_end = 1395
    _globals["_SCHEDULEWORKLINEUPDATEREQUEST"]._serialized_start = 1398
    _globals["_SCHEDULEWORKLINEUPDATEREQUEST"]._serialized_end = 1577
    _globals["_SCHEDULEWORKLINEUPDATERESPONSE"]._serialized_start = 1580
    _globals["_SCHEDULEWORKLINEUPDATERESPONSE"]._serialized_end = 1779
    _globals["_SCHEDULEWORKLINEDELETEREQUEST"]._serialized_start = 1781
    _globals["_SCHEDULEWORKLINEDELETEREQUEST"]._serialized_end = 1880
    _globals["_SCHEDULEWORKLINEDELETERESPONSE"]._serialized_start = 1882
    _globals["_SCHEDULEWORKLINEDELETERESPONSE"]._serialized_end = 1989
    _globals["_SCHEDULEWORKLINESERVICE"]._serialized_start = 1992
    _globals["_SCHEDULEWORKLINESERVICE"]._serialized_end = 2747
# @@protoc_insertion_point(module_scope)



import importlib
import inspect
import pkgutil
from contextlib import ExitStack

from mongoengine import Document
from mongoengine import context_managers as ctx_mgr
from mongoengine import fields
from omni.pro.models.base import BaseDocument
from omni.pro.topology import Topology


class ExitStackDocument(ExitStack):
    """
    Context manager for dynamic management of an outbound callback stack for Documents.

    For example:
        with ExitStackDocument([DocumentClass1, DocumentClass2], "db_alias") as stack:
            DocumentClass1.objects.all()
            # All documents are swiched to their respective aliases.
    """

    def __init__(self, document_classes: list = [], db_alias="", *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.document_classes = self.__reference_models_services()
        self.db_alias = db_alias
        self.model_classes = []

    def __enter__(self):
        for document_class in self.document_classes:
            self.model_classes = self.enter_context(ctx_mgr.switch_db(document_class, self.db_alias))
        return super().__enter__()

    def __reference_models_services(self):
        return Topology().get_models_from_libs()


class ExitStackDocumentMicro(ExitStackDocument):
    """
    Context manager for dynamic management of an outbound callback stack for user microservice documents.

    For example:
        with ExitStackDocumentMicro("db_alias") as stack:
            pass
            # All documents in models package are swiched to their respective db_alias.
    """

    def __init__(self, db_alias=None, *args, **kwargs):
        super().__init__(document_classes=[], db_alias=db_alias, *args, **kwargs)

    def __enter__(self):
        self.document_classes = self.get_document_classes()
        return super().__enter__()

    def get_document_classes(self):
        # El nombre de tu paquete (la carpeta que contiene los módulos)
        package_name = "models"

        # Busca todos los módulos en el paquete
        package = importlib.import_module(package_name)
        modules = [name for _, name, _ in pkgutil.iter_modules(package.__path__)]

        document_classes = []
        # Importa cada módulo y busca las clases de tipo Document
        for module_name in modules:
            module = importlib.import_module(f"{package_name}.{module_name}")

            for name, obj in inspect.getmembers(module):
                if (
                    inspect.isclass(obj)
                    and issubclass(obj, Document)
                    and obj != Document
                    and obj != BaseDocument
                    and obj not in document_classes
                ):
                    document_classes.append(obj)
                    for field in self.get_reference_fields_and_classes(obj):
                        if field not in document_classes:
                            document_classes.append(field)

        return document_classes

    def get_reference_fields_and_classes(self, doc):
        ref_fields = []
        for name, field in doc._fields.items():
            if isinstance(field, fields.ReferenceField):
                ref_fields.append(field.document_type)
            elif isinstance(field, fields.ListField) and isinstance(field.field, fields.ReferenceField):
                ref_fields.append(field.field.document_type)
        return ref_fields



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/holidays.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17v1/rules/holidays.proto\x12"pro.omni.oms.api.v1.rules.holidays\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xb4\x01\n\x08Holidays\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x03 \x03(\t\x12*\n\x06\x61\x63tive\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x80\x01\n\x15HolidaysCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x02 \x03(\t\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16HolidaysCreateResponse\x12>\n\x08holidays\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.holidays.Holidays\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf1\x02\n\x13HolidaysReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdc\x01\n\x14HolidaysReadResponse\x12>\n\x08holidays\x18\x01 \x03(\x0b\x32,.pro.omni.oms.api.v1.rules.holidays.Holidays\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8f\x01\n\x15HolidaysUpdateRequest\x12>\n\x08holidays\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.holidays.Holidays\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16HolidaysUpdateResponse\x12>\n\x08holidays\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.holidays.Holidays\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"[\n\x15HolidaysDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16HolidaysDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xbb\x04\n\x0fHolidaysService\x12\x89\x01\n\x0eHolidaysCreate\x12\x39.pro.omni.oms.api.v1.rules.holidays.HolidaysCreateRequest\x1a:.pro.omni.oms.api.v1.rules.holidays.HolidaysCreateResponse"\x00\x12\x83\x01\n\x0cHolidaysRead\x12\x37.pro.omni.oms.api.v1.rules.holidays.HolidaysReadRequest\x1a\x38.pro.omni.oms.api.v1.rules.holidays.HolidaysReadResponse"\x00\x12\x89\x01\n\x0eHolidaysUpdate\x12\x39.pro.omni.oms.api.v1.rules.holidays.HolidaysUpdateRequest\x1a:.pro.omni.oms.api.v1.rules.holidays.HolidaysUpdateResponse"\x00\x12\x89\x01\n\x0eHolidaysDelete\x12\x39.pro.omni.oms.api.v1.rules.holidays.HolidaysDeleteRequest\x1a:.pro.omni.oms.api.v1.rules.holidays.HolidaysDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.holidays_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_HOLIDAYS"]._serialized_start = 115
    _globals["_HOLIDAYS"]._serialized_end = 295
    _globals["_HOLIDAYSCREATEREQUEST"]._serialized_start = 298
    _globals["_HOLIDAYSCREATEREQUEST"]._serialized_end = 426
    _globals["_HOLIDAYSCREATERESPONSE"]._serialized_start = 429
    _globals["_HOLIDAYSCREATERESPONSE"]._serialized_end = 592
    _globals["_HOLIDAYSREADREQUEST"]._serialized_start = 595
    _globals["_HOLIDAYSREADREQUEST"]._serialized_end = 964
    _globals["_HOLIDAYSREADRESPONSE"]._serialized_start = 967
    _globals["_HOLIDAYSREADRESPONSE"]._serialized_end = 1187
    _globals["_HOLIDAYSUPDATEREQUEST"]._serialized_start = 1190
    _globals["_HOLIDAYSUPDATEREQUEST"]._serialized_end = 1333
    _globals["_HOLIDAYSUPDATERESPONSE"]._serialized_start = 1336
    _globals["_HOLIDAYSUPDATERESPONSE"]._serialized_end = 1499
    _globals["_HOLIDAYSDELETEREQUEST"]._serialized_start = 1501
    _globals["_HOLIDAYSDELETEREQUEST"]._serialized_end = 1592
    _globals["_HOLIDAYSDELETERESPONSE"]._serialized_start = 1594
    _globals["_HOLIDAYSDELETERESPONSE"]._serialized_end = 1693
    _globals["_HOLIDAYSSERVICE"]._serialized_start = 1696
    _globals["_HOLIDAYSSERVICE"]._serialized_end = 2267
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class DeliveryPriceWarehouse(_message.Message):
    __slots__ = ["id", "delivery_price_id", "warehouse_id", "active", "external_id", "object_audit"]
    ID_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_PRICE_ID_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: int
    delivery_price_id: int
    warehouse_id: int
    active: bool
    external_id: str
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[int] = ...,
        delivery_price_id: _Optional[int] = ...,
        warehouse_id: _Optional[int] = ...,
        active: bool = ...,
        external_id: _Optional[str] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceWarehouseCreateRequest(_message.Message):
    __slots__ = ["delivery_price_id", "warehouse_id", "external_id", "context"]
    DELIVERY_PRICE_ID_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_ID_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_price_id: int
    warehouse_id: int
    external_id: str
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_price_id: _Optional[int] = ...,
        warehouse_id: _Optional[int] = ...,
        external_id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceWarehouseCreateResponse(_message.Message):
    __slots__ = ["delivery_price_warehouse", "response_standard"]
    DELIVERY_PRICE_WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_price_warehouse: DeliveryPriceWarehouse
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_price_warehouse: _Optional[_Union[DeliveryPriceWarehouse, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceWarehouseReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceWarehouseReadResponse(_message.Message):
    __slots__ = ["delivery_price_warehouse", "meta_data", "response_standard"]
    DELIVERY_PRICE_WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_price_warehouse: _containers.RepeatedCompositeFieldContainer[DeliveryPriceWarehouse]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_price_warehouse: _Optional[_Iterable[_Union[DeliveryPriceWarehouse, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceWarehouseUpdateRequest(_message.Message):
    __slots__ = ["delivery_price_warehouse", "context"]
    DELIVERY_PRICE_WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_price_warehouse: DeliveryPriceWarehouse
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_price_warehouse: _Optional[_Union[DeliveryPriceWarehouse, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceWarehouseUpdateResponse(_message.Message):
    __slots__ = ["delivery_price_warehouse", "response_standard"]
    DELIVERY_PRICE_WAREHOUSE_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_price_warehouse: DeliveryPriceWarehouse
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_price_warehouse: _Optional[_Union[DeliveryPriceWarehouse, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryPriceWarehouseDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: int
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class DeliveryPriceWarehouseDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/clients/address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x18v1/clients/address.proto\x12#pro.omni.oms.api.v1.clients.address\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto"\xba\x02\n\x07\x41\x64\x64ress\x12\x12\n\ncountry_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x14\n\x0ctype_address\x18\x04 \x01(\t\x12\x0e\n\x06street\x18\x05 \x01(\t\x12\x0f\n\x07street2\x18\x06 \x01(\t\x12\x0b\n\x03lat\x18\x07 \x01(\t\x12\x0b\n\x03lng\x18\x08 \x01(\t\x12\x10\n\x08zip_code\x18\t \x01(\t\x12\x36\n\x12territory_matrixes\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x0e\n\x06\x61\x63tive\x18\x0b \x01(\x08\x12\x13\n\x0b\x65xternal_id\x18\x0c \x01(\t\x12?\n\x0cobject_audit\x18\r \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xc1\x02\n\x14\x41\x64\x64ressCreateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x12\n\ncountry_id\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0ctype_address\x18\x05 \x01(\t\x12\x0e\n\x06street\x18\x06 \x01(\t\x12\x0f\n\x07street2\x18\x07 \x01(\t\x12\x0b\n\x03lat\x18\x08 \x01(\t\x12\x0b\n\x03lng\x18\t \x01(\t\x12\x10\n\x08zip_code\x18\n \x01(\t\x12\x36\n\x12territory_matrixes\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x13\n\x0b\x65xternal_id\x18\x0c \x01(\t\x12\x36\n\x07\x63ontext\x18\r \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa1\x01\n\x15\x41\x64\x64ressCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12=\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32,.pro.omni.oms.api.v1.clients.address.Address"\xa0\x01\n\x14\x41\x64\x64ressUpdateRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12=\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32,.pro.omni.oms.api.v1.clients.address.Address\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa1\x01\n\x15\x41\x64\x64ressUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12=\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32,.pro.omni.oms.api.v1.clients.address.Address"o\n\x14\x41\x64\x64ressDeleteRequest\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15\x41\x64\x64ressDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xb3\x03\n\x10\x41\x64\x64ressesService\x12\x88\x01\n\rAddressCreate\x12\x39.pro.omni.oms.api.v1.clients.address.AddressCreateRequest\x1a:.pro.omni.oms.api.v1.clients.address.AddressCreateResponse"\x00\x12\x88\x01\n\rAddressUpdate\x12\x39.pro.omni.oms.api.v1.clients.address.AddressUpdateRequest\x1a:.pro.omni.oms.api.v1.clients.address.AddressUpdateResponse"\x00\x12\x88\x01\n\rAddressDelete\x12\x39.pro.omni.oms.api.v1.clients.address.AddressDeleteRequest\x1a:.pro.omni.oms.api.v1.clients.address.AddressDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.clients.address_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_ADDRESS"]._serialized_start = 115
    _globals["_ADDRESS"]._serialized_end = 429
    _globals["_ADDRESSCREATEREQUEST"]._serialized_start = 432
    _globals["_ADDRESSCREATEREQUEST"]._serialized_end = 753
    _globals["_ADDRESSCREATERESPONSE"]._serialized_start = 756
    _globals["_ADDRESSCREATERESPONSE"]._serialized_end = 917
    _globals["_ADDRESSUPDATEREQUEST"]._serialized_start = 920
    _globals["_ADDRESSUPDATEREQUEST"]._serialized_end = 1080
    _globals["_ADDRESSUPDATERESPONSE"]._serialized_start = 1083
    _globals["_ADDRESSUPDATERESPONSE"]._serialized_end = 1244
    _globals["_ADDRESSDELETEREQUEST"]._serialized_start = 1246
    _globals["_ADDRESSDELETEREQUEST"]._serialized_end = 1357
    _globals["_ADDRESSDELETERESPONSE"]._serialized_start = 1359
    _globals["_ADDRESSDELETERESPONSE"]._serialized_end = 1457
    _globals["_ADDRESSESSERVICE"]._serialized_start = 1460
    _globals["_ADDRESSESSERVICE"]._serialized_end = 1895
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/flow.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.sales import state_pb2 as v1_dot_sales_dot_state__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13v1/sales/flow.proto\x12\x1epro.omni.oms.api.v1.sales.flow\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x14v1/sales/state.proto"\x84\x02\n\x04\x46low\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12=\n\rinitial_state\x18\x04 \x01(\x0b\x32&.pro.omni.oms.api.v1.sales.state.State\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x07 \x01(\t\x12?\n\x0cobject_audit\x18\x08 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xab\x01\n\x11\x46lowCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x18\n\x10initial_state_id\x18\x03 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x12\x46lowCreateResponse\x12\x32\n\x04\x66low\x18\x01 \x01(\x0b\x32$.pro.omni.oms.api.v1.sales.flow.Flow\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xed\x02\n\x0f\x46lowReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xcd\x01\n\x10\x46lowReadResponse\x12\x33\n\x05\x66lows\x18\x01 \x03(\x0b\x32$.pro.omni.oms.api.v1.sales.flow.Flow\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x7f\n\x11\x46lowUpdateRequest\x12\x32\n\x04\x66low\x18\x01 \x01(\x0b\x32$.pro.omni.oms.api.v1.sales.flow.Flow\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x12\x46lowUpdateResponse\x12\x32\n\x04\x66low\x18\x01 \x01(\x0b\x32$.pro.omni.oms.api.v1.sales.flow.Flow\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"W\n\x11\x46lowDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"_\n\x12\x46lowDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe3\x03\n\x0b\x46lowService\x12u\n\nFlowCreate\x12\x31.pro.omni.oms.api.v1.sales.flow.FlowCreateRequest\x1a\x32.pro.omni.oms.api.v1.sales.flow.FlowCreateResponse"\x00\x12o\n\x08\x46lowRead\x12/.pro.omni.oms.api.v1.sales.flow.FlowReadRequest\x1a\x30.pro.omni.oms.api.v1.sales.flow.FlowReadResponse"\x00\x12u\n\nFlowUpdate\x12\x31.pro.omni.oms.api.v1.sales.flow.FlowUpdateRequest\x1a\x32.pro.omni.oms.api.v1.sales.flow.FlowUpdateResponse"\x00\x12u\n\nFlowDelete\x12\x31.pro.omni.oms.api.v1.sales.flow.FlowDeleteRequest\x1a\x32.pro.omni.oms.api.v1.sales.flow.FlowDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.flow_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_FLOW"]._serialized_start = 129
    _globals["_FLOW"]._serialized_end = 389
    _globals["_FLOWCREATEREQUEST"]._serialized_start = 392
    _globals["_FLOWCREATEREQUEST"]._serialized_end = 563
    _globals["_FLOWCREATERESPONSE"]._serialized_start = 566
    _globals["_FLOWCREATERESPONSE"]._serialized_end = 713
    _globals["_FLOWREADREQUEST"]._serialized_start = 716
    _globals["_FLOWREADREQUEST"]._serialized_end = 1081
    _globals["_FLOWREADRESPONSE"]._serialized_start = 1084
    _globals["_FLOWREADRESPONSE"]._serialized_end = 1289
    _globals["_FLOWUPDATEREQUEST"]._serialized_start = 1291
    _globals["_FLOWUPDATEREQUEST"]._serialized_end = 1418
    _globals["_FLOWUPDATERESPONSE"]._serialized_start = 1421
    _globals["_FLOWUPDATERESPONSE"]._serialized_end = 1568
    _globals["_FLOWDELETEREQUEST"]._serialized_start = 1570
    _globals["_FLOWDELETEREQUEST"]._serialized_end = 1657
    _globals["_FLOWDELETERESPONSE"]._serialized_start = 1659
    _globals["_FLOWDELETERESPONSE"]._serialized_end = 1754
    _globals["_FLOWSERVICE"]._serialized_start = 1757
    _globals["_FLOWSERVICE"]._serialized_end = 2240
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class ComputeMethodData(_message.Message):
    __slots__ = ["cart_details", "items", "shipping_details"]
    CART_DETAILS_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    SHIPPING_DETAILS_FIELD_NUMBER: _ClassVar[int]
    cart_details: _struct_pb2.Struct
    items: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    shipping_details: _struct_pb2.Struct
    def __init__(
        self,
        cart_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        items: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        shipping_details: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
    ) -> None: ...

class ComputeMethodRequest(_message.Message):
    __slots__ = ["version", "data", "context"]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    version: int
    data: _containers.RepeatedCompositeFieldContainer[ComputeMethodData]
    context: _base_pb2.Context
    def __init__(
        self,
        version: _Optional[int] = ...,
        data: _Optional[_Iterable[_Union[ComputeMethodData, _Mapping]]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ComputeMethodResponse(_message.Message):
    __slots__ = ["result", "response_standard"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    result: _struct_pb2.ListValue
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        result: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class ComputeMethodStockAvailableRequest(_message.Message):
    __slots__ = ["methods", "items", "context"]
    METHODS_FIELD_NUMBER: _ClassVar[int]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    methods: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    items: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    context: _base_pb2.Context
    def __init__(
        self,
        methods: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        items: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ComputeMethodStockAvailableResponse(_message.Message):
    __slots__ = ["result", "response_standard"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    result: _struct_pb2.ListValue
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        result: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class ComputeDeliveryCarrierData(_message.Message):
    __slots__ = ["address", "products", "warehouse_sql_id", "delivery_method_doc_id", "internal_transfer"]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PRODUCTS_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_SQL_ID_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_METHOD_DOC_ID_FIELD_NUMBER: _ClassVar[int]
    INTERNAL_TRANSFER_FIELD_NUMBER: _ClassVar[int]
    address: _struct_pb2.Struct
    products: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    warehouse_sql_id: int
    delivery_method_doc_id: str
    internal_transfer: _wrappers_pb2.BoolValue
    def __init__(
        self,
        address: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        products: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        warehouse_sql_id: _Optional[int] = ...,
        delivery_method_doc_id: _Optional[str] = ...,
        internal_transfer: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
    ) -> None: ...

class ComputeDeliveryCarrierRequest(_message.Message):
    __slots__ = ["data", "context"]
    DATA_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    data: ComputeDeliveryCarrierData
    context: _base_pb2.Context
    def __init__(
        self,
        data: _Optional[_Union[ComputeDeliveryCarrierData, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class ComputeDeliveryCarrierResponse(_message.Message):
    __slots__ = ["carrier_sql_id", "response_standard"]
    CARRIER_SQL_ID_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    carrier_sql_id: int
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        carrier_sql_id: _Optional[int] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class QueryExportRequest(_message.Message):
    __slots__ = ["model_path", "query", "date_init", "date_finish", "fields", "context"]
    MODEL_PATH_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    DATE_INIT_FIELD_NUMBER: _ClassVar[int]
    DATE_FINISH_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    model_path: str
    query: str
    date_init: _timestamp_pb2.Timestamp
    date_finish: _timestamp_pb2.Timestamp
    fields: _containers.RepeatedScalarFieldContainer[str]
    context: _base_pb2.Context
    def __init__(
        self,
        model_path: _Optional[str] = ...,
        query: _Optional[str] = ...,
        date_init: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        date_finish: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...,
        fields: _Optional[_Iterable[str]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class QueryExportResponse(_message.Message):
    __slots__ = ["response_standard", "result"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    result: _struct_pb2.ListValue
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        result: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
    ) -> None: ...



from typing import ClassVar as _ClassVar
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class BatchUpsertRequest(_message.Message):
    __slots__ = ["tenant", "model_path", "models", "context"]
    TENANT_FIELD_NUMBER: _ClassVar[int]
    MODEL_PATH_FIELD_NUMBER: _ClassVar[int]
    MODELS_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    tenant: str
    model_path: str
    models: _struct_pb2.ListValue
    context: _base_pb2.Context
    def __init__(
        self,
        tenant: _Optional[str] = ...,
        model_path: _Optional[str] = ...,
        models: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class BatchUpsertResponse(_message.Message):
    __slots__ = ["error_models", "response_standard"]
    ERROR_MODELS_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    error_models: _struct_pb2.ListValue
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        error_models: _Optional[_Union[_struct_pb2.ListValue, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.stock import picking_type_pb2 as v1_dot_stock_dot_picking__type__pb2


class PickingTypeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PickingTypeCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeCreate",
            request_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateResponse.FromString,
        )
        self.PickingTypeRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeRead",
            request_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeReadRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeReadResponse.FromString,
        )
        self.PickingTypeUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeUpdate",
            request_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateResponse.FromString,
        )
        self.PickingTypeDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeDelete",
            request_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteResponse.FromString,
        )


class PickingTypeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def PickingTypeCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def PickingTypeDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_PickingTypeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "PickingTypeCreate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeCreate,
            request_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateResponse.SerializeToString,
        ),
        "PickingTypeRead": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeRead,
            request_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeReadRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeReadResponse.SerializeToString,
        ),
        "PickingTypeUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeUpdate,
            request_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateResponse.SerializeToString,
        ),
        "PickingTypeDelete": grpc.unary_unary_rpc_method_handler(
            servicer.PickingTypeDelete,
            request_deserializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteRequest.FromString,
            response_serializer=v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.stock.picking_type.PickingTypeService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class PickingTypeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def PickingTypeCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeCreate",
            v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateRequest.SerializeToString,
            v1_dot_stock_dot_picking__type__pb2.PickingTypeCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeRead",
            v1_dot_stock_dot_picking__type__pb2.PickingTypeReadRequest.SerializeToString,
            v1_dot_stock_dot_picking__type__pb2.PickingTypeReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeUpdate",
            v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateRequest.SerializeToString,
            v1_dot_stock_dot_picking__type__pb2.PickingTypeUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def PickingTypeDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.stock.picking_type.PickingTypeService/PickingTypeDelete",
            v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteRequest.SerializeToString,
            v1_dot_stock_dot_picking__type__pb2.PickingTypeDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/sales/picking.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/sales/picking.proto\x12!pro.omni.oms.api.v1.sales.picking\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x63ommon/base.proto"\xcf\x01\n\x07Picking\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08order_id\x18\x03 \x01(\x05\x12\x16\n\x0epicking_sql_id\x18\x04 \x01(\x05\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x06 \x01(\t\x12?\n\x0cobject_audit\x18\x07 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x9b\x01\n\x14PickingCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08order_id\x18\x02 \x01(\x05\x12\x16\n\x0epicking_sql_id\x18\x03 \x01(\x05\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15PickingCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07picking\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.picking.Picking"\xf0\x02\n\x12PickingReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd9\x01\n\x13PickingReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12<\n\x08pickings\x18\x03 \x03(\x0b\x32*.pro.omni.oms.api.v1.sales.picking.Picking"\x8b\x01\n\x14PickingUpdateRequest\x12;\n\x07picking\x18\x01 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.picking.Picking\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x9f\x01\n\x15PickingUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12;\n\x07picking\x18\x02 \x01(\x0b\x32*.pro.omni.oms.api.v1.sales.picking.Picking"Z\n\x14PickingDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15PickingDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xa5\x04\n\x0ePickingService\x12\x84\x01\n\rPickingCreate\x12\x37.pro.omni.oms.api.v1.sales.picking.PickingCreateRequest\x1a\x38.pro.omni.oms.api.v1.sales.picking.PickingCreateResponse"\x00\x12~\n\x0bPickingRead\x12\x35.pro.omni.oms.api.v1.sales.picking.PickingReadRequest\x1a\x36.pro.omni.oms.api.v1.sales.picking.PickingReadResponse"\x00\x12\x84\x01\n\rPickingUpdate\x12\x37.pro.omni.oms.api.v1.sales.picking.PickingUpdateRequest\x1a\x38.pro.omni.oms.api.v1.sales.picking.PickingUpdateResponse"\x00\x12\x84\x01\n\rPickingDelete\x12\x37.pro.omni.oms.api.v1.sales.picking.PickingDeleteRequest\x1a\x38.pro.omni.oms.api.v1.sales.picking.PickingDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.sales.picking_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PICKING"]._serialized_start = 113
    _globals["_PICKING"]._serialized_end = 320
    _globals["_PICKINGCREATEREQUEST"]._serialized_start = 323
    _globals["_PICKINGCREATEREQUEST"]._serialized_end = 478
    _globals["_PICKINGCREATERESPONSE"]._serialized_start = 481
    _globals["_PICKINGCREATERESPONSE"]._serialized_end = 640
    _globals["_PICKINGREADREQUEST"]._serialized_start = 643
    _globals["_PICKINGREADREQUEST"]._serialized_end = 1011
    _globals["_PICKINGREADRESPONSE"]._serialized_start = 1014
    _globals["_PICKINGREADRESPONSE"]._serialized_end = 1231
    _globals["_PICKINGUPDATEREQUEST"]._serialized_start = 1234
    _globals["_PICKINGUPDATEREQUEST"]._serialized_end = 1373
    _globals["_PICKINGUPDATERESPONSE"]._serialized_start = 1376
    _globals["_PICKINGUPDATERESPONSE"]._serialized_end = 1535
    _globals["_PICKINGDELETEREQUEST"]._serialized_start = 1537
    _globals["_PICKINGDELETEREQUEST"]._serialized_end = 1627
    _globals["_PICKINGDELETERESPONSE"]._serialized_start = 1629
    _globals["_PICKINGDELETERESPONSE"]._serialized_end = 1727
    _globals["_PICKINGSERVICE"]._serialized_start = 1730
    _globals["_PICKINGSERVICE"]._serialized_end = 2279
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import warehouse_hierarchy_pb2 as v1_dot_rules_dot_warehouse__hierarchy__pb2


class WarehouseHierarchyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WarehouseHierarchyCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyCreate",
            request_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateResponse.FromString,
        )
        self.WarehouseHierarchyRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyRead",
            request_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadResponse.FromString,
        )
        self.WarehouseHierarchyUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyUpdate",
            request_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateResponse.FromString,
        )
        self.WarehouseHierarchyDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyDelete",
            request_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteResponse.FromString,
        )


class WarehouseHierarchyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def WarehouseHierarchyCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseHierarchyRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseHierarchyUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseHierarchyDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_WarehouseHierarchyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "WarehouseHierarchyCreate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseHierarchyCreate,
            request_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateResponse.SerializeToString,
        ),
        "WarehouseHierarchyRead": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseHierarchyRead,
            request_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadResponse.SerializeToString,
        ),
        "WarehouseHierarchyUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseHierarchyUpdate,
            request_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateResponse.SerializeToString,
        ),
        "WarehouseHierarchyDelete": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseHierarchyDelete,
            request_deserializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class WarehouseHierarchyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def WarehouseHierarchyCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyCreate",
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseHierarchyRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyRead",
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseHierarchyUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyUpdate",
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseHierarchyDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse_hierarchy.WarehouseHierarchyService/WarehouseHierarchyDelete",
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__hierarchy__pb2.WarehouseHierarchyDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_locality.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import country_pb2 as v1_dot_rules_dot_country__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n v1/rules/delivery_locality.proto\x12+pro.omni.oms.api.v1.rules.delivery_locality\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x16v1/rules/country.proto"\xef\x02\n\x10\x44\x65liveryLocality\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12;\n\x07\x63ountry\x18\x03 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.country.Country\x12\x17\n\x0f\x63ode_collection\x18\x04 \x01(\t\x12)\n\x05items\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x07 \x01(\t\x12>\n\x1dterritory_matrix_values_front\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf6\x01\n\x1d\x44\x65liveryLocalityCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncountry_id\x18\x02 \x01(\t\x12\x17\n\x0f\x63ode_collection\x18\x03 \x01(\t\x12\r\n\x05items\x18\x04 \x03(\t\x12\x13\n\x0b\x65xternal_id\x18\x05 \x01(\t\x12>\n\x1dterritory_matrix_values_front\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x1e\x44\x65liveryLocalityCreateResponse\x12X\n\x11\x64\x65livery_locality\x18\x01 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocality\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf9\x02\n\x1b\x44\x65liveryLocalityReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x80\x02\n\x1c\x44\x65liveryLocalityReadResponse\x12Z\n\x13\x64\x65livery_localities\x18\x01 \x03(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocality\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xb1\x01\n\x1d\x44\x65liveryLocalityUpdateRequest\x12X\n\x11\x64\x65livery_locality\x18\x01 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocality\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc5\x01\n\x1e\x44\x65liveryLocalityUpdateResponse\x12X\n\x11\x64\x65livery_locality\x18\x01 \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocality\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"c\n\x1d\x44\x65liveryLocalityDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"k\n\x1e\x44\x65liveryLocalityDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xeb\x05\n\x17\x44\x65liveryLocalityService\x12\xb3\x01\n\x16\x44\x65liveryLocalityCreate\x12J.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityCreateRequest\x1aK.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityCreateResponse"\x00\x12\xad\x01\n\x14\x44\x65liveryLocalityRead\x12H.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityReadRequest\x1aI.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityReadResponse"\x00\x12\xb3\x01\n\x16\x44\x65liveryLocalityUpdate\x12J.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityUpdateRequest\x1aK.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityUpdateResponse"\x00\x12\xb3\x01\n\x16\x44\x65liveryLocalityDelete\x12J.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityDeleteRequest\x1aK.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocalityDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_locality_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYLOCALITY"]._serialized_start = 187
    _globals["_DELIVERYLOCALITY"]._serialized_end = 554
    _globals["_DELIVERYLOCALITYCREATEREQUEST"]._serialized_start = 557
    _globals["_DELIVERYLOCALITYCREATEREQUEST"]._serialized_end = 803
    _globals["_DELIVERYLOCALITYCREATERESPONSE"]._serialized_start = 806
    _globals["_DELIVERYLOCALITYCREATERESPONSE"]._serialized_end = 1003
    _globals["_DELIVERYLOCALITYREADREQUEST"]._serialized_start = 1006
    _globals["_DELIVERYLOCALITYREADREQUEST"]._serialized_end = 1383
    _globals["_DELIVERYLOCALITYREADRESPONSE"]._serialized_start = 1386
    _globals["_DELIVERYLOCALITYREADRESPONSE"]._serialized_end = 1642
    _globals["_DELIVERYLOCALITYUPDATEREQUEST"]._serialized_start = 1645
    _globals["_DELIVERYLOCALITYUPDATEREQUEST"]._serialized_end = 1822
    _globals["_DELIVERYLOCALITYUPDATERESPONSE"]._serialized_start = 1825
    _globals["_DELIVERYLOCALITYUPDATERESPONSE"]._serialized_end = 2022
    _globals["_DELIVERYLOCALITYDELETEREQUEST"]._serialized_start = 2024
    _globals["_DELIVERYLOCALITYDELETEREQUEST"]._serialized_end = 2123
    _globals["_DELIVERYLOCALITYDELETERESPONSE"]._serialized_start = 2125
    _globals["_DELIVERYLOCALITYDELETERESPONSE"]._serialized_end = 2232
    _globals["_DELIVERYLOCALITYSERVICE"]._serialized_start = 2235
    _globals["_DELIVERYLOCALITYSERVICE"]._serialized_end = 2982
# @@protoc_insertion_point(module_scope)
